@@ -9,7 +9,7 @@ use Digest::SHA();
 use WebService::HIBP::Breach();
 use WebService::HIBP::Paste();
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 sub _LENGTH_OF_PASSWORD_PREFIX { return 5; }
 
@@ -154,7 +154,7 @@ WebService::HIBP - An interface to the Have I Been Pwned webservice at haveibeen
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =head1 SYNOPSIS
 
@@ -189,7 +189,7 @@ The L<Pwned Passwords API|https://haveibeenpwned.com/API/v2#PwnedPasswords> has
 
 In order to protect the value of the source password being searched for, this method implements a L<k-Anonymity|https://en.wikipedia.org/wiki/K-anonymity> model that searches for a password by partial hash. This method therefore only sends the first 5 characters of a SHA-1 hash of the password (the prefix) to the L<Pwned Passwords API|https://haveibeenpwned.com/API/v2#PwnedPasswords>.
 
-The L<Pwned Passwords API|https://haveibeenpwned.com/API/v2#PwnedPasswords> responds with a list of the suffix of every hash beginning with the specified prefix, followed by a count of how many times it appears in the data set. This method then searches the results of the response for the presence of a matching hash suffix.
+The L<Pwned Passwords API|https://haveibeenpwned.com/API/v2#PwnedPasswords> responds with a list of the suffix of every hash beginning with the specified prefix, followed by a count of how many times it appears in the data set. This method searches the results of the response for a matching hash suffix.
 
 This method then returns the count of how many times it appears in the data set or "0" if it dosen't appear.
 
